Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Transcribe.

Actions, resources, and condition keys for Amazon Transcribe - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Transcribe

Amazon Transcribe (service prefix: `transcribe` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Amazon Transcribe
- Resource types defined by Amazon Transcribe
- Condition keys for Amazon Transcribe

## Actions defined by Amazon Transcribe

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateLanguageModel | Grants permission to create a new custom language model. | Write |  |  | s3:GetObject s3:ListBucket
CreateMedicalVocabulary | Grants permission to create a new custom vocabulary that you can use to change the way Amazon Transcribe Medical handles transcription of an audio file. | Write |  |  | s3:GetObject
CreateVocabulary | Grants permission to create a new custom vocabulary that you can use to change the way Amazon Transcribe handles transcription of an audio file. | Write |  |  | s3:GetObject
CreateVocabularyFilter | Grants permission to create a new vocabulary filter that you can use to filter out words from the transcription of an audio file generated by Amazon Transcribe | Write |  |  | s3:GetObject
DeleteLanguageModel | Grants permission to delete a previously created custom language model. | Write |  |  |
DeleteMedicalTranscriptionJob | Grants permission to delete a previously submitted medical transcription job. | Write |  |  |
DeleteMedicalVocabulary | Grants permission to delete a medical vocabulary from Amazon Transcribe. | Write |  |  |
DeleteTranscriptionJob | Grants permission to delete a previously submitted transcription job along with any other generated results such as the transcription, models, and so on. | Write |  |  |
DeleteVocabulary | Grants permission to delete a vocabulary from Amazon Transcribe. | Write |  |  |
DeleteVocabularyFilter | Grants permission to delete a vocabulary filter from Amazon Transcribe. | Write |  |  |
DescribeLanguageModel | Grants permission to return information about a custom language model. | Read |  |  |
GetMedicalTranscriptionJob | Grants permission to return information about a medical transcription job. | Read |  |  |
GetMedicalVocabulary | Grants permission to get information about a medical vocabulary. | Read |  |  |
GetTranscriptionJob | Grants permission to return information about a transcription job. | Read |  |  |
GetVocabulary | Grants permission to to get information about a vocabulary. | Read |  |  |
GetVocabularyFilter | Grants permission to get information about a vocabulary filter. | Read |  |  |
ListLanguageModels | Grants permission to list custom language models. | List |  |  |
ListMedicalTranscriptionJobs | Grants permission to list medical transcription jobs with the specified status. | List |  |  |
ListMedicalVocabularies | Grants permission to return a list of medical vocabularies that match the specified criteria. If no criteria are specified, returns the entire list of vocabularies. | List |  |  |
ListTranscriptionJobs | Grants permission to list transcription jobs with the specified status. | List |  |  |
ListVocabularies | Grants permission to return a list of vocabularies that match the specified criteria. If no criteria are specified, returns the entire list of vocabularies. | List |  |  |
ListVocabularyFilters | Grants permission to return a list of vocabulary filters that match the specified criteria. If no criteria are specified, returns the at most 5 vocabulary filters. | List |  |  |
StartMedicalStreamTranscription | Grants permission to start a protocol where audio is streamed to Transcribe Medical and the transcription results are streamed to your application. | Write |  |  |
StartMedicalStreamTranscriptionWebSocket | Grants permission to start a WebSocket where audio is streamed to Transcribe Medical and the transcription results are streamed to your application. | Write |  |  |
StartMedicalTranscriptionJob | Grants permission to start an asynchronous job to transcribe medical speech to text. | Write |  |  | s3:GetObject
StartStreamTranscription | Grants permission to start a bidirectional HTTP2 stream to transcribe speech to text in real time. | Write |  |  |
StartStreamTranscriptionWebSocket | Grants permission to start a websocket stream to transcribe speech to text in real time. | Write |  |  |
StartTranscriptionJob | Grants permission to start an asynchronous job to transcribe speech to text. | Write |  | transcribe:OutputBucketName transcribe:OutputEncryptionKMSKeyId transcribe:OutputKey | s3:GetObject
UpdateMedicalVocabulary | Grants permission to update an existing medical vocabulary with new values. The UpdateMedicalVocabulary operation overwrites all of the existing information with the values that you provide in the request. | Write |  |  | s3:GetObject
UpdateVocabulary | Grants permission to update an existing vocabulary with new values. The UpdateVocabulary operation overwrites all of the existing information with the values that you provide in the request. | Write |  |  | s3:GetObject
UpdateVocabularyFilter | Grants permission to update an existing vocabulary filter with new values. The UpdateVocabularyFilter operation overwrites all of the existing information with the values that you provide in the request. | Write |  |  | s3:GetObject

## Resource types defined by Amazon Transcribe

Amazon Transcribe does not support specifying a resource ARN in the `Resource` element of an IAM policy statement. To allow access to Amazon Transcribe, specify `“Resource”: “*”` in your policy.

## Condition keys for Amazon Transcribe

Amazon Transcribe defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
transcribe:OutputBucketName | Enables you to control access based on the output bucket name included in the request | String
transcribe:OutputEncryptionKMSKeyId | Enables you to control access based on the KMS key id included in the request | String
transcribe:OutputKey | Enables you to control access based on the output key included in the request | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.